@@ -24,8 +24,8 @@
 class DurationLogObject extends LogObject {
 	var $duration;
 	
-	function DurationLogObject($user, $db, $duration) {
-		$this->LogObject($user, $db);
+	function DurationLogObject($connectionId, $user, $db, $duration) {
+		$this->LogObject($connectionId, $user, $db);
 		$this->duration = $duration;
 	}
 	
