@@ -30,8 +30,10 @@ require_once('LogStream.class.php');
 
 require_once('LogObject.class.php');
 require_once('QueryLogObject.class.php');
+require_once('PreparedStatementLogObject.class.php');
 require_once('DurationLogObject.class.php');
 require_once('ErrorLogObject.class.php');
+require_once('UselessLogObject.class.php');
 
 require_once('GenericLogReader.class.php');
 require_once('SlowestQueryList.class.php');
