@@ -25,7 +25,9 @@ class PostgreSQLStatementLine extends PostgreSQLQueryStartLine {
 	var $ignore = false;
 
 	function appendTo(& $logObject) {
-		$logObject->appendStatement($this->text);
+		if(is_a($logObject, 'ErrorLogObject')) {
+			$logObject->appendStatement($this->text);
+		}
 	}
 }
 
