@@ -34,7 +34,7 @@ class PostgreSQLParser {
 			$postMatch = $logLineMatch->getPostMatch();
 			
 			if($keyword == 'LOG' || $keyword == 'DEBUG') {
-				$queryMatch =& $postgreSQLRegexps['QueryStartPart']->match($postMatch);
+				$queryMatch =& $postgreSQLRegexps['RegularQueryStartPart']->match($postMatch);
 				if($queryMatch) {
 					$line = new PostgreSQLQueryStartLine($queryMatch->getPostMatch());
 				} elseif($durationMatch =& $postgreSQLRegexps['DurationPart']->match($postMatch)) {
@@ -42,10 +42,45 @@ class PostgreSQLParser {
 					if($additionalInformation == '') {
 						$line = new PostgreSQLDurationLine(trim($durationMatch->getMatch(1)), $durationMatch->getMatch(2));
 					} else {
-						$line = new PostgreSQLQueryStartWithDurationLine($additionalInformation, trim($durationMatch->getMatch(1)), $durationMatch->getMatch(2));
+						$additionalInformation = $postgreSQLRegexps['QueryStartPart']->replace($additionalInformation, '');
+						if($preparedStatementMatch =& $postgreSQLRegexps['PreparedStatementPart']->match($additionalInformation)) {
+							$action = strtolower($preparedStatementMatch->getMatch(1));
+							$statementInformation = explode('/', $preparedStatementMatch->getMatch(2));
+							if(count($statementInformation) > 1) {
+								$preparedStatementName = $statementInformation[0];
+								$portalName = $statementInformation[1];
+							} else {
+								$preparedStatementName = $statementInformation[0];
+								$portalName = '';
+							}
+							$text = $preparedStatementMatch->getPostMatch();
+							if($action == 'execute') {
+								$line = new PostgreSQLPreparedStatementExecuteWithDurationLine($preparedStatementName, $portalName, $text, trim($durationMatch->getMatch(1)), $durationMatch->getMatch(2));
+							} else {
+								$line = new PostgreSQLPreparedStatementUselessLine();
+							}
+						} else {
+							$line = new PostgreSQLQueryStartWithDurationLine($additionalInformation, trim($durationMatch->getMatch(1)), $durationMatch->getMatch(2));
+						}
 					}
 				} elseif($statusMatch =& $postgreSQLRegexps['StatusPart']->match($postMatch)) {
-						$line = new PostgreSQLStatusLine($postMatch);
+					$line = new PostgreSQLStatusLine($postMatch);
+				} elseif($preparedStatementMatch =& $postgreSQLRegexps['PreparedStatementPart']->match($postgreSQLRegexps['QueryStartPart']->replace($postMatch, ''))) {
+					$action = strtolower($preparedStatementMatch->getMatch(1));
+					$statementInformation = explode('/', $preparedStatementMatch->getMatch(2));
+					if(count($statementInformation) > 1) {
+						$preparedStatementName = $statementInformation[0];
+						$portalName = $statementInformation[1];
+					} else {
+						$preparedStatementName = $statementInformation[0];
+						$portalName = '';
+					}
+					$text = $preparedStatementMatch->getPostMatch();
+					if($action == 'execute' || $action == 'execute from fetch') {
+						$line = new PostgreSQLPreparedStatementExecuteLine($preparedStatementName, $portalName, $text);
+					} else {
+						$line = new PostgreSQLPreparedStatementUselessLine();
+					}
 				} else {
 					// we ignore a lot of common log lines as they are not interesting
 					// but we still raise an error if we don't recognize a log line
