@@ -50,7 +50,7 @@ class NormalizedQueriesMostTimeReport extends NormalizedReport {
 		<th>Rank</th>
 		<th>Total duration</th>
 		<th>Times executed</th>
-		<th>Av. duration&nbsp;(s)</th>
+		<th>Av.&nbsp;duration&nbsp;('.CONFIG_DURATION_UNIT.')</th>
 		<th>Query</th>
 	</tr>';
 		$queries =& $listener->getQueriesMostTime();
